==> knative-model-4.9.0-sources.jar: io/fabric8/knative/serving/v1alpha1/RouteStatusFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.knative.v1.URLFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.v1.URL;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.duck.v1alpha1.AddressableFluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.v1.URLBuilder;
import io.fabric8.knative.v1.ConditionBuilder;
import java.lang.StringBuffer;
import io.fabric8.knative.duck.v1alpha1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.duck.v1alpha1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface RouteStatusFluent<A extends io.fabric8.knative.serving.v1alpha1.RouteStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public io.fabric8.knative.duck.v1alpha1.Addressable getAddress();
    public io.fabric8.knative.duck.v1alpha1.Addressable buildAddress();
    public A withAddress(io.fabric8.knative.duck.v1alpha1.Addressable address);
    public Boolean hasAddress();
    public RouteStatusFluent.V1alpha1AddressNested<A> withNewV1alpha1Address();
    public RouteStatusFluent.V1alpha1AddressNested<A> withNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public RouteStatusFluent.V1alpha1AddressNested<A> editV1alpha1Address();
    public RouteStatusFluent.V1alpha1AddressNested<A> editOrNewAddress();
    public RouteStatusFluent.V1alpha1AddressNested<A> editOrNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public RouteStatusFluent.ConditionsNested<A> addNewCondition();
    public RouteStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public RouteStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public RouteStatusFluent.ConditionsNested<A> editCondition(int index);
    public RouteStatusFluent.ConditionsNested<A> editFirstCondition();
    public RouteStatusFluent.ConditionsNested<A> editLastCondition();
    public RouteStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public String getDomain();
    public A withDomain(String domain);
    public Boolean hasDomain();
    public A withNewDomain(String arg1);
    public A withNewDomain(StringBuilder arg1);
    public A withNewDomain(StringBuffer arg1);
    public String getDomainInternal();
    public A withDomainInternal(String domainInternal);
    public Boolean hasDomainInternal();
    public A withNewDomainInternal(String arg1);
    public A withNewDomainInternal(StringBuilder arg1);
    public A withNewDomainInternal(StringBuffer arg1);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A addToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public A setToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public A addToTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items);
    public A addAllToTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items);
    public A removeFromTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items);
    public A removeAllFromTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items);
    public A removeMatchingFromTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> getTraffic();
    public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> buildTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildTraffic(int index);
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildFirstTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildLastTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    public Boolean hasMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    public A withTraffic(List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> traffic);
    public A withTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... traffic);
    public Boolean hasTraffic();
    public RouteStatusFluent.TrafficNested<A> addNewTraffic();
    public RouteStatusFluent.TrafficNested<A> addNewTrafficLike(io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public RouteStatusFluent.TrafficNested<A> setNewTrafficLike(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public RouteStatusFluent.TrafficNested<A> editTraffic(int index);
    public RouteStatusFluent.TrafficNested<A> editFirstTraffic();
    public RouteStatusFluent.TrafficNested<A> editLastTraffic();
    public RouteStatusFluent.TrafficNested<A> editMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildUrl instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public URL getUrl();
    public URL buildUrl();
    public A withUrl(URL url);
    public Boolean hasUrl();
    public RouteStatusFluent.UrlNested<A> withNewUrl();
    public RouteStatusFluent.UrlNested<A> withNewUrlLike(URL item);
    public RouteStatusFluent.UrlNested<A> editUrl();
    public RouteStatusFluent.UrlNested<A> editOrNewUrl();
    public RouteStatusFluent.UrlNested<A> editOrNewUrlLike(URL item);

    public interface V1alpha1AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.duck.v1alpha1.AddressableFluent<RouteStatusFluent.V1alpha1AddressNested<N>>{

        
    public N and();    public N endAddress();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<RouteStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface TrafficNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.TrafficTargetFluent<RouteStatusFluent.TrafficNested<N>>{

        
    public N and();    public N endTraffic();
}
    public interface UrlNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,URLFluent<RouteStatusFluent.UrlNested<N>>{

        
    public N and();    public N endUrl();
}


}

==> knative-model-4.10.1-sources.jar: io/fabric8/knative/serving/v1alpha1/RouteStatusFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.duck.v1alpha1.AddressableFluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.v1.ConditionBuilder;
import java.lang.StringBuffer;
import io.fabric8.knative.duck.v1alpha1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.duck.v1alpha1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface RouteStatusFluent<A extends io.fabric8.knative.serving.v1alpha1.RouteStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public io.fabric8.knative.duck.v1alpha1.Addressable getAddress();
    public io.fabric8.knative.duck.v1alpha1.Addressable buildAddress();
    public A withAddress(io.fabric8.knative.duck.v1alpha1.Addressable address);
    public Boolean hasAddress();
    public A withNewV1alpha1Address(String hostname,String url);
    public RouteStatusFluent.V1alpha1AddressNested<A> withNewV1alpha1Address();
    public RouteStatusFluent.V1alpha1AddressNested<A> withNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public RouteStatusFluent.V1alpha1AddressNested<A> editV1alpha1Address();
    public RouteStatusFluent.V1alpha1AddressNested<A> editOrNewAddress();
    public RouteStatusFluent.V1alpha1AddressNested<A> editOrNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public RouteStatusFluent.ConditionsNested<A> addNewCondition();
    public RouteStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public RouteStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public RouteStatusFluent.ConditionsNested<A> editCondition(int index);
    public RouteStatusFluent.ConditionsNested<A> editFirstCondition();
    public RouteStatusFluent.ConditionsNested<A> editLastCondition();
    public RouteStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public String getDomain();
    public A withDomain(String domain);
    public Boolean hasDomain();
    public A withNewDomain(String arg1);
    public A withNewDomain(StringBuilder arg1);
    public A withNewDomain(StringBuffer arg1);
    public String getDomainInternal();
    public A withDomainInternal(String domainInternal);
    public Boolean hasDomainInternal();
    public A withNewDomainInternal(String arg1);
    public A withNewDomainInternal(StringBuilder arg1);
    public A withNewDomainInternal(StringBuffer arg1);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A addToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public A setToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public A addToTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items);
    public A addAllToTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items);
    public A removeFromTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items);
    public A removeAllFromTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items);
    public A removeMatchingFromTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> getTraffic();
    public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> buildTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildTraffic(int index);
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildFirstTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildLastTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    public Boolean hasMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    public A withTraffic(List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> traffic);
    public A withTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... traffic);
    public Boolean hasTraffic();
    public RouteStatusFluent.TrafficNested<A> addNewTraffic();
    public RouteStatusFluent.TrafficNested<A> addNewTrafficLike(io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public RouteStatusFluent.TrafficNested<A> setNewTrafficLike(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public RouteStatusFluent.TrafficNested<A> editTraffic(int index);
    public RouteStatusFluent.TrafficNested<A> editFirstTraffic();
    public RouteStatusFluent.TrafficNested<A> editLastTraffic();
    public RouteStatusFluent.TrafficNested<A> editMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    public String getUrl();
    public A withUrl(String url);
    public Boolean hasUrl();
    public A withNewUrl(String arg1);
    public A withNewUrl(StringBuilder arg1);
    public A withNewUrl(StringBuffer arg1);

    public interface V1alpha1AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.duck.v1alpha1.AddressableFluent<RouteStatusFluent.V1alpha1AddressNested<N>>{

        
    public N and();    public N endAddress();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<RouteStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface TrafficNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.TrafficTargetFluent<RouteStatusFluent.TrafficNested<N>>{

        
    public N and();    public N endTraffic();
}


}
